﻿using System;
using System.Windows;
using System.ComponentModel.Composition;
using System.ComponentModel.Composition.Hosting;

using Utils.Silverlight.MVVM;
using Utils.Demo.ContosoSales.MVVM.Views;

namespace Utils.Demo.ContosoSales
{
    public partial class App : Application
    {
        /// <summary>
        /// The main view will be imported by MEF.
        /// </summary>
        [Import]
        public MainView MainView
        {
            get { return RootVisual as MainView; }
            set { RootVisual = value; }
        }

        public App()
        {
            InitializeComponent();         
        }

        /// <summary>
        /// When the application starts, start doing our registrations and then import the required objects.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void OnStart(object sender, StartupEventArgs e)
        {
            // Initialize the container using a deployment catalog.
            var catalog = new DeploymentCatalog();            
            var container = CompositionHost.Initialize(catalog);

            // Export the container as singleton.
            container.ComposeExportedValue<CompositionContainer>(container);
           
            // Make sure the MainView is imported.
            CompositionInitializer.SatisfyImports(this);
        }

        /// <summary>
        /// Show error on exception.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void OnException(object sender, ApplicationUnhandledExceptionEventArgs e)
        {
            if (!System.Diagnostics.Debugger.IsAttached)
            {
                e.Handled = true;
                ErrorWindow w = new ErrorWindow(e.ExceptionObject);
                w.Show();
            }
        }
    }
}