﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel.Composition;

namespace Utils.Demo.ContosoSales.MVVM.Model
{
    [Export(typeof(IDataService))]
    public class DummyDataService : IDataService
    {
        /// <summary>
        /// Internal list of customers.
        /// </summary>
        private static List<Customer> customers;

        /// <summary>
        /// Internal list of employees.
        /// </summary>
        private static List<Employee> employees;

        public DummyDataService()
        {
            EnsureCustomers();
            EnsureEmployees();
        }

        /// <summary>
        /// Ensure the employees list.
        /// </summary>
        private void EnsureEmployees()
        {
            if (employees == null)
            {
                employees = new List<Employee>();
                employees.Add(new Employee()
                {
                    Age = 23, Firstname = "Sandrino", IsManagement = false, IsSales = true, Lastname = "Di Mattia"
                });
                employees.Add(new Employee()
                {
                    Age = 23, Firstname = "User 1", IsManagement = false, IsSales = true, Lastname = "User 1"
                });
                employees.Add(new Employee()
                {
                    Age = 39, Firstname = "User 2", IsManagement = true, IsSales = false, Lastname = "User 2" 
                });
            }
        }

        /// <summary>
        /// Ensure the customers list.
        /// </summary>
        private void EnsureCustomers()
        {
            if (customers == null)
            { 
                customers = new List<Customer>();
                customers.Add(new Customer()
                {
                    Id = 0, City = "City 0", Company = "Company 0", CustomerSince = 1980, Email = "info@company0.com", Sold = 8000, Street = "My Street 0"
                });
                customers.Add(new Customer()
                {
                    Id = 1, City = "City 1", Company = "Company 1", CustomerSince = 2000, Email = "info@company1.com", Sold = 1266388, Street = "My Street 1"
                });
                customers.Add(new Customer()
                {
                    Id = 2, City = "City 2", Company = "Company 2", CustomerSince = 2002, Email = "info@company2.com", Sold = 9983, Street = "My Street 2"
                });
                customers.Add(new Customer()
                {
                    Id = 3, City = "City 3", Company = "Company 3", CustomerSince = 2005, Email = "info@company3.com", Sold = 8839, Street = "My Street 3"
                });
                customers.Add(new Customer()
                {
                    Id = 4, City = "City 4", Company = "Company 4", CustomerSince = 2008, Email = "info@company4.com", Sold = 2049, Street = "My Street 4"
                });
            }
        }
        
        /// <summary>
        /// Get the customers list.
        /// </summary>
        /// <returns></returns>
        public List<Customer> GetCustomers()
        {
            return customers;
        }

        /// <summary>
        /// Find a customer.
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        public Customer GetCustomerById(int id)
        {
            return customers.FirstOrDefault(o => o.Id == id);
        }
        
        /// <summary>
        /// Get the employees list.
        /// </summary>
        /// <returns></returns>
        public List<Employee> GetEmployees()
        {
            return employees;
        }

        /// <summary>
        /// Find an employee.
        /// </summary>
        /// <param name="lastname"></param>
        /// <returns></returns>
        public Employee GetEmployeeByLastname(string lastname)
        {
            return employees.FirstOrDefault(o => o.Lastname.Replace(" ", "") == lastname);
        }
    }
}
