﻿using System;
using System.ComponentModel.Composition;

using GalaSoft.MvvmLight;

using Utils.Silverlight.MVVM;
using Utils.Silverlight.MVVM.Navigation;

namespace Utils.Demo.ContosoSales.MVVM.ViewModels
{
    public abstract class ContosoViewModelBase : ViewModelBase, IViewModel
    {
        /// <summary>
        /// The navigation service allows you to navigate to an other ViewModel.
        /// </summary>
        [Import]
        public INavigationService NavigationService { get; set; }

        /// <summary>
        /// Method will be called once the ViewModel is completely loaded and attached to the View.
        /// </summary>
        public virtual void OnLoaded()
        {
            System.Diagnostics.Debug.WriteLine(NavigationService.GetHashCode());
        }

        /// <summary>
        /// Method will be called once the navigation is done.
        /// The args will contain all arguments that were passed while navigating.
        /// </summary>
        /// <param name="args"></param>
        public virtual void OnNavigated(NavigationArguments args)
        {

        }

        /// <summary>
        /// Get the title to display after navigating.
        /// </summary>
        /// <returns></returns>
        public string GetTitle()
        {
            return "Contoso Sales / " + GetViewTitle() ;
        }

        /// <summary>
        /// Make sure each ViewModel can provide a title.
        /// </summary>
        /// <returns></returns>
        public abstract string GetViewTitle();
    }
}
