﻿using System;
using System.Windows.Input;
using System.ComponentModel.Composition;

using Utils.Silverlight.MVVM;
using Utils.Silverlight.MVVM.Navigation;

using Utils.Demo.ContosoSales.MVVM.Model;

using GalaSoft.MvvmLight.Command;

namespace Utils.Demo.ContosoSales.MVVM.ViewModels
{
    [ViewModelExport(typeof(ICustomerDetailViewModel), "Customer/{id}")]
    public class CustomerDetailViewModel : ContosoViewModelBase, ICustomerDetailViewModel
    {
        /// <summary>
        /// The data service.
        /// </summary>
        /// <value></value>
        [Import]
        public IDataService DataService { get; set; }

        /// <summary>
        /// Cancel command.
        /// </summary>
        public ICommand CancelCommand { get; set; }

        /// <summary>
        /// Close event mapped to the View.
        /// </summary>
        public event EventHandler CloseView;

        /// <summary>
        /// Customer field.
        /// </summary>
        private Customer customer;

        /// <summary>
        /// Customer.
        /// </summary>
        public Customer Customer
        {
            get { return customer; }
            set
            {
                customer = value;
                RaisePropertyChanged("Customer");
            }
        }

        /// <summary>
        /// Raise the close event so we can close the view.
        /// </summary>
        public void RaiseClose()
        {
            if (CloseView != null)
                CloseView(this, null);
        }

        public CustomerDetailViewModel()
        {
            CancelCommand = new RelayCommand(RaiseClose);
        }

        /// <summary>
        /// Get the customer's id after navigating and load the customer.
        /// </summary>
        /// <param name="args"></param>
        public override void OnNavigated(NavigationArguments args)
        {
            var id = args.GetInt("Id");
            if (id.HasValue)
            {
                Customer = DataService.GetCustomerById(id.Value);
            }
        }

        /// <summary>
        /// Provide the customer's company name as title.
        /// </summary>
        /// <returns></returns>
        public override string GetViewTitle()
        {
            if (Customer != null)
                return Customer.Company;
            else
                return "Customer Detail";
        }
    }
}
