﻿using System;
using System.Windows.Input;
using System.Collections.Generic;
using System.ComponentModel.Composition;

using GalaSoft.MvvmLight.Command;

using Utils.Silverlight.MVVM;
using Utils.Demo.ContosoSales.MVVM.Model;

namespace Utils.Demo.ContosoSales.MVVM.ViewModels
{
    [ViewModelExport(typeof(ICustomersViewModel), "Customers")]
    public class CustomersViewModel : ContosoViewModelBase, ICustomersViewModel
    {
        #region Properties & Fields
        /// <summary>
        /// Service giving access to the data.
        /// </summary>
        [Import]
        public IDataService DataService { get; set; }

        /// <summary>
        /// Open customer command.
        /// </summary>
        public ICommand OpenCustomerCommand { get; set; }

        /// <summary>
        /// Help command.
        /// </summary>
        public ICommand HelpCommand { get; set; }

        /// <summary>
        /// Customer field.
        /// </summary>
        private Customer selectedCustomer;

        /// <summary>
        /// Current customer.
        /// </summary>
        public Customer SelectedCustomer
        {
            get { return selectedCustomer; }
            set
            {
                selectedCustomer = value;
                RaisePropertyChanged("SelectedCustomer");

                // Refresh the command.
                var openCustomerRelay = OpenCustomerCommand as RelayCommand;
                openCustomerRelay.RaiseCanExecuteChanged();
            }
        }

        /// <summary>
        /// Internal customers field.
        /// </summary>
        private List<Customer> customers;

        /// <summary>
        /// List of customers.
        /// </summary>
        public List<Customer> Customers
        {
            get { return customers; }
            set
            {
                customers = value;
                RaisePropertyChanged("Customers");
            }
        }
        #endregion

        /// <summary>
        /// Initialize the ViewModel to create the commands.
        /// </summary>
        public CustomersViewModel()
        {
            HelpCommand = new RelayCommand(OnHelp);
            OpenCustomerCommand = new RelayCommand(OnOpenCustomer, CanOpenCustomer);
        }

        /// <summary>
        /// Can the customer be opened.
        /// </summary>
        /// <returns></returns>
        private bool CanOpenCustomer()
        {
            return SelectedCustomer != null;
        }

        /// <summary>
        /// Open the selected customer.
        /// </summary>
        private void OnOpenCustomer()
        {
            NavigationService.Navigate("Customer/{0}", SelectedCustomer.Id);
        }

        /// <summary>
        /// Navigate for help.
        /// </summary>
        private void OnHelp()
        {
            NavigationService.Navigate("Help/{0}", "Customers");
        }

        /// <summary>
        /// Once the ViewModel is loaded the DataService will be imported.
        /// After that get the cutomer list.
        /// </summary>
        public override void OnLoaded()
        {
            Customers = DataService.GetCustomers();
        }

        public override string GetViewTitle()
        {
            return "Customers";
        }
    }
}
