﻿using System;
using System.ComponentModel.Composition;

using Utils.Silverlight.MVVM;
using Utils.Silverlight.MVVM.Navigation;

using Utils.Demo.ContosoSales.MVVM.Model;

namespace Utils.Demo.ContosoSales.MVVM.ViewModels
{
    [ViewModelExport(typeof(IEmployeeDetailViewModel), "Employee/{lastname}")]
    public class EmployeeDetailViewModel : ContosoViewModelBase, IEmployeeDetailViewModel
    {
        /// <summary>
        /// The service giving access to the data.
        /// </summary>
        [Import]
        public IDataService DataService { get; set; }
        
        /// <summary>
        /// Employee field.
        /// </summary>
        private Employee employee;

        /// <summary>
        /// The current employee.
        /// </summary>
        public Employee Employee
        {
            get { return employee; }
            set
            {
                employee = value;
                RaisePropertyChanged("Employee");
            }
        }

        /// <summary>
        /// After navigating get the employee's name and load the employee.
        /// </summary>
        /// <param name="args"></param>
        public override void OnNavigated(NavigationArguments args)
        {
            var lastname = args.GetString("lastname");
            if (lastname != null)
            {
                Employee = DataService.GetEmployeeByLastname(lastname);
            }
        }

        /// <summary>
        /// Get the employee's lastname as title.
        /// </summary>
        /// <returns></returns>
        public override string GetViewTitle()
        {
            if (Employee != null)
                return Employee.Lastname;
            else
                return "Employee Detail";
        }
    }
}
