﻿using System;
using System.Windows.Input;
using System.Windows.Browser;
using System.Windows.Controls;
using System.Collections.Generic;

using GalaSoft.MvvmLight.Command;

using Utils.Silverlight.MVVM;
using Utils.Silverlight.MVVM.Navigation;

namespace Utils.Demo.ContosoSales.MVVM.ViewModels
{
    [ViewModelExport(typeof(IHelpViewModel), "Help/{Topic}")]
    public class HelpViewModel : ContosoViewModelBase, IHelpViewModel
    {
        /// <summary>
        /// Help text to show.
        /// </summary>
        public string HelpText { get; set; }

        /// <summary>
        /// What is the user searching for.
        /// </summary>
        public string SearchText { get; set; }

        /// <summary>
        /// Close event.
        /// </summary>
        public event EventHandler CloseView;

        /// <summary>
        /// Close.
        /// </summary>
        public ICommand CloseCommand { get; set; }

        /// <summary>
        /// Search.
        /// </summary>
        public ICommand SearchCommand { get; set; }

        /// <summary>
        /// Initialize the ViewModel.
        /// </summary>
        public HelpViewModel()
        {
            HelpText = "Enter a query and press Search.\r\nThis will launch Bing.com and you might get an answer to your question there.";
            CloseCommand = new RelayCommand(OnClose);
            SearchCommand = new RelayCommand(OnSearch);
        }

        /// <summary>
        /// When navigated, get the topic and enter this in the Search box.
        /// </summary>
        /// <param name="args"></param>
        public override void OnNavigated(NavigationArguments args)
        {
            if (args.ContainsKey("Topic"))
            {
                SearchText = args["Topic"] as string;
                RaisePropertyChanged("SearchText");
            }
        }

        /// <summary>
        /// Launch the search.
        /// </summary>
        private void OnSearch()
        {
            // Format the search url.
            string searchUrl = "http://www.bing.com/search?q=Contoso+{0}";
            searchUrl = String.Format(searchUrl, SearchText);

            // Open the new browser window.
            HtmlPage.PopupWindow(new Uri(searchUrl), "",
                new HtmlPopupWindowOptions());
        }

        /// <summary>
        /// Close the ViewModel.
        /// </summary>
        public void OnClose()
        {
            if (CloseView != null)
                CloseView(this, null);
        }

        /// <summary>
        /// Get the title based on the search text.
        /// </summary>
        /// <returns></returns>
        public override string GetViewTitle()
        {
            if (SearchText == null)
                return "Help";
            else
                return "Help: " + SearchText;
        }
    }
}
