﻿using System;
using System.Linq;
using System.Windows.Input;
using System.Collections.Generic;
using System.ComponentModel.Composition;

using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Command;

using Utils.Silverlight.MVVM;
using Utils.Demo.ContosoSales.MVVM.Model;

namespace Utils.Demo.ContosoSales.MVVM.ViewModels
{
    [ViewModelExport(typeof(ISalesTeamViewModel), "SalesTeam")]
    public class SalesTeamViewModel : ContosoViewModelBase, ISalesTeamViewModel
    {
        [Import]
        public IDataService DataService { get; set; }

        /// <summary>
        /// Open employee command.
        /// </summary>
        public ICommand OpenEmployeeCommand { get; set; }

        /// <summary>
        /// Navigate to help command.
        /// </summary>
        public ICommand HelpCommand { get; set; }

        /// <summary>
        /// Selected employee field.
        /// </summary>
        private Employee selectedEmployee;

        /// <summary>
        /// Current employee.
        /// </summary>
        public Employee SelectedEmployee
        {
            get { return selectedEmployee; }
            set
            {
                selectedEmployee = value;
                RaisePropertyChanged("SelectedEmployee");

                // Refresh the command.
                var openCustomerRelay = OpenEmployeeCommand as RelayCommand;
                openCustomerRelay.RaiseCanExecuteChanged();
            }
        }

        /// <summary>
        /// Employees field.
        /// </summary>
        private List<Employee> employees;

        /// <summary>
        /// The employees list.
        /// </summary>
        public List<Employee> Employees
        {
            get { return employees; }
            set
            {
                employees = value;
                RaisePropertyChanged("Employees");
            }
        }

        /// <summary>
        /// Initialize the commands.
        /// </summary>
        public SalesTeamViewModel()
        {
            HelpCommand = new RelayCommand(OnHelp);
            OpenEmployeeCommand = new RelayCommand(OnOpenEmployee, CanOpenCustomer);
        }

        /// <summary>
        /// Can an employee be opened.
        /// </summary>
        /// <returns></returns>
        private bool CanOpenCustomer()
        {
            return SelectedEmployee != null;
        }

        /// <summary>
        /// Open a customer.
        /// </summary>
        private void OnOpenEmployee()
        {
            NavigationService.Navigate("Employee/{0}", SelectedEmployee.Lastname.Replace(" ", ""));
        }

        /// <summary>
        /// Navigate to Help.
        /// </summary>
        private void OnHelp()
        {
            NavigationService.Navigate("Help/{0}", "Sales Team");
        }

        /// <summary>
        /// Load the employees once the DataService has been imported.
        /// This happens after loading the ViewModel.
        /// </summary>
        public override void OnLoaded()
        {
            Employees = DataService.GetEmployees().Where(o => o.IsSales).ToList();
        }

        /// <summary>
        /// Custom title for the view.
        /// </summary>
        /// <returns></returns>
        public override string GetViewTitle()
        {
            return "Sales Team";
        }
    }
}
