﻿using System;
using System.Linq;
using System.Reflection;
using System.Collections.Generic;
using System.ComponentModel.Composition;

using Utils.Silverlight.MVVM.Navigation;

namespace Utils.Silverlight.MVVM
{
    [MetadataAttribute]
    [AttributeUsage(AttributeTargets.Class, AllowMultiple = false)]
    public class ViewModelExportAttribute : ExportAttribute, IViewModelMetadata
    {
        /// <summary>
        /// The actual interface of the ViewModel.
        /// This type will be used to match a View to a ViewModel.
        /// </summary>
        /// <value></value>
        public Type ViewModelContract { get; set; }

        /// <summary>
        /// Specify to which navigation key this ViewModel should be mapped.
        /// Eg: 'Customers', or 'Customer/1'
        /// </summary>
        public string NavigationPath { get; set; }

        /// <summary>
        /// This is the actual navigation key. 
        /// 'Customer/1' would have as key: 'Customer'.
        /// </summary>
        public string Key { get; set; }
        
        /// <summary>
        /// Initialize the attribute by defining the contract of the ViewModel and the navigation key.
        /// This viewModelContract should be the same as the one used by the ViewExport attribute.
        /// </summary>
        /// <param name="viewModelContract"></param>
        /// <param name="navigationPath"></param>
        public ViewModelExportAttribute(Type viewModelContract, string navigationPath)
            : base(typeof(IViewModel))
        {
            this.NavigationPath = navigationPath;
            this.ViewModelContract = viewModelContract;

            if (NavigationPath != null && NavigationPath.Contains("/"))
            {
                // Split the path to get the arguments.
                var split = NavigationPath.Split(new char[] { '/' }, StringSplitOptions.RemoveEmptyEntries);

                // Get the key.
                Key = split[0];
            }
            else
            {
                // No arguments, use the whole key.
                Key = NavigationPath;
            }
        }        
    }
}
