﻿using System;
using System.Threading;
using System.Windows.Controls;

namespace Utils.Silverlight.MVVM
{
    /// <summary>
    /// A regular class implementing IAsyncResult.
    /// </summary>
    internal class CompositionNavigationAsyncResult : IAsyncResult
    {
        /// <summary>
        /// The resulting control after the navigation.
        /// </summary>
        public object Result { get; set; }

        /// <summary>
        /// Gets a user-defined object that qualifies or contains information about an asynchronous operation.
        /// </summary>
        public object AsyncState { get; private set; }

        /// <summary>
        /// Gets a System.Threading.WaitHandle that is used to wait for an asynchronous operation to complete.
        /// </summary>
        public WaitHandle AsyncWaitHandle { get; private set; }

        /// <summary>
        /// Gets a value that indicates whether the asynchronous operation completed synchronously.
        /// </summary>
        public bool CompletedSynchronously 
        {
            get { return true; }
        }

        /// <summary>
        /// Gets a value that indicates whether the asynchronous operation has completed.
        /// </summary>
        public bool IsCompleted
        {
            get { return true; }
        }

        /// <summary>
        /// Initialize the navigation result by passing the state and the control).
        /// </summary>
        /// <param name="state"></param>
        /// <param name="result"></param>
        public CompositionNavigationAsyncResult(object state, Control control)
        {
            this.Result = control;
            this.AsyncState = state;
            this.AsyncWaitHandle = new ManualResetEvent(true);
        }
    }
}
