﻿using System;
using System.Windows.Controls;
using System.Windows.Navigation;
using System.Windows.Interactivity;

using System.ComponentModel;
using System.ComponentModel.Composition;
using System.ComponentModel.Composition.Hosting;

using Utils.Silverlight.MVVM.Navigation;

namespace Utils.Silverlight.MVVM
{
    public class CompositionNavigationBehavior : Behavior<Frame>
    {
        /// <summary>
        /// Flag to prevent double processing of the behavior.
        /// </summary>
        private bool processed;

        /// <summary>
        /// The container that will allow instance registration.
        /// </summary>
        [Import]
        public CompositionContainer Container { get; set; }

        /// <summary>
        /// The loader that will process navigation requests.
        /// </summary>
        [Import]
        public CompositionNavigationContentLoader Loader { get; set; }

        /// <summary>
        /// Initialize the behavior by importing the required objects.
        /// </summary>
        public CompositionNavigationBehavior()
        {
            if (!DesignerProperties.IsInDesignTool)
                CompositionInitializer.SatisfyImports(this);
        }

        /// <summary>
        /// Once the frame has been attached, start processing it.
        /// </summary>
        protected override void OnAttached()
        {
            base.OnAttached();

            if (!processed)
            {
                this.RegisterNavigationService();
                this.SetContentLoader();
                processed = true;
            }
        }

        /// <summary>
        /// Create and register a navigation service.
        /// </summary>
        private void RegisterNavigationService()
        {
            // Wrap the frame in a navigation service.
            var frame = AssociatedObject;
            var svc = new Utils.Silverlight.MVVM.Navigation.NavigationService(frame);

            // Register the navigation service as a singleton instance.
            Container.ComposeExportedValue<INavigationService>(svc);
        }

        /// <summary>
        /// Set the content loader in the frame.
        /// </summary>
        private void SetContentLoader()
        {
            var frame = AssociatedObject;
            frame.ContentLoader = Loader;
            frame.JournalOwnership = JournalOwnership.Automatic;
        }
    }
}
