﻿using System;
using System.Collections.Generic;

namespace Utils.Silverlight.MVVM.Navigation
{
    public static class NavigationArgumentExtensions
    {
        /// <summary>
        /// Process the metadata's Path to extract the Arguments.
        /// </summary>
        /// <param name="md">The ViewModel's metadata.</param>
        /// <returns></returns>
        public static List<string> GetArguments(this IViewModelMetadata metadata)
        {
            // New list holding the arguments.
            var args = new List<string>();

            // Only process if the Path is valid.
            if (metadata.NavigationPath != null && metadata.NavigationPath.Contains("/"))
            {
                // Split the path to get the arguments.
                var split = metadata.NavigationPath.Split(new char[] { '/' }, StringSplitOptions.RemoveEmptyEntries);

                // Add each argument.
                for (int i = 1; i < split.Length; i++)
                {
                    string arg = split[i];
                    arg = arg.Trim('{', '}');
                    args.Add(arg);
                }
            }

            // Done.
            return args;
        }

        /// <summary>
        /// Get the values for the arguments (if any).
        /// </summary>
        /// <param name="metadata">The ViewModel's metadata.</param>
        /// <param name="navigationUri">The navigation URI.</param>
        /// <returns></returns>
        public static NavigationArguments GetArgumentValues(this IViewModelMetadata metadata, Uri navigationUri)
        {
            // Dictionary holding the values.
            var values = new NavigationArguments();

            // Process values.
            if (navigationUri.OriginalString.Contains("/"))
            {
                // Split the path to get the values.
                var split = navigationUri.OriginalString.Split(new char[] { '/' }, StringSplitOptions.RemoveEmptyEntries);

                // Get the arguments from the metadata.
                var args = metadata.GetArguments();

                // Add each value.
                for (int i = 1; i < split.Length; i++)
                {
                    if (args.Count >= i)
                        values.Add(args[i - 1], split[i]);
                }
            }

            // Done.
            return values;
        }
    }
}
