﻿using System;
using System.Linq;
using System.Collections.Generic;

namespace Utils.Silverlight.MVVM.Navigation
{
    public class NavigationArguments : Dictionary<string, string>
    {
        /// <summary>
        /// Get argument as integer.
        /// </summary>
        /// <param name="key"></param>
        /// <returns></returns>
        public int? GetInt(string key)
        {
            return GetValue<int?>(key, (v) => Convert.ToInt32(v));
        }

        /// <summary>
        /// Get argument as datetime.
        /// </summary>
        /// <param name="key"></param>
        /// <returns></returns>
        public DateTime? GetDateTime(string key)
        {
            return GetValue<DateTime?>(key, (v) => DateTime.Parse(v));
        }

        /// <summary>
        /// Get argument as guid.
        /// </summary>
        /// <param name="key"></param>
        /// <returns></returns>
        public Guid? GetGuid(string key)
        {
            return GetValue<Guid?>(key, (v) => new Guid(v));
        }

        /// <summary>
        /// Get argument as string.
        /// </summary>
        /// <param name="key"></param>
        /// <returns></returns>
        public string GetString(string key)
        {
            return GetValue<string>(key, (v) => v);
        }

        /// <summary>
        /// Helper method to get typed argument.
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="key"></param>
        /// <param name="convertFunc"></param>
        /// <returns></returns>
        private T GetValue<T>(string key, Func<string, T> convertFunc)
        {
            // Get the default value for this type.
            T value = default(T);

            // Try to find the matching key and get its value if possible.
            var keyResult = Keys.FirstOrDefault(o => o.Equals(key, StringComparison.OrdinalIgnoreCase));
            if (keyResult != null)
                value = convertFunc(this[keyResult]);

            // Done.
            return value;
        }
    }
}
