﻿using System;
using System.Windows.Controls;
using System.ComponentModel.Composition;

namespace Utils.Silverlight.MVVM.Navigation
{
    /// <summary>
    /// Wrapper for <see cref="Frame"/> to abstract the navigation process.
    /// </summary>
    [Export(typeof(INavigationService))]
    public class NavigationService : INavigationService
    {
        /// <summary>
        /// The frame doing the actual navigation.
        /// </summary>
        private Frame navigationFrame;

        /// <summary>
        /// Initialize the service by storing the frame.
        /// </summary>
        /// <param name="navigationFrame"></param>
        public NavigationService(Frame navigationFrame)
        {
            this.navigationFrame = navigationFrame;
        }

        /// <summary>
        /// Navigate to a given path.
        /// </summary>
        /// <param name="path"></param>
        public void Navigate(string path)
        {
            navigationFrame.Navigate(new Uri(path, UriKind.Relative));
        }

        /// <summary>
        /// Navigate to a given path and process some arguments.
        /// </summary>
        /// <param name="path"></param>
        /// <param name="args"></param>
        public void Navigate(string path, params object[] args)
        {
            Navigate(String.Format(path, args));
        }
    }
}
